Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(912)

Unified Diff: chrome/browser/ui/autofill/popup_controller_common.h

Issue 2762233004: Fix autofill popup controller key press callback registration (Closed)
Patch Set: Address comments Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/autofill/popup_controller_common.h
diff --git a/chrome/browser/ui/autofill/popup_controller_common.h b/chrome/browser/ui/autofill/popup_controller_common.h
index 45edaec72c87e76493a6a2f3950a1dd98071db16..b540810330ea8429640080edb4941371984d2ac8 100644
--- a/chrome/browser/ui/autofill/popup_controller_common.h
+++ b/chrome/browser/ui/autofill/popup_controller_common.h
@@ -12,7 +12,6 @@
#include "ui/gfx/native_widget_types.h"
namespace content {
-class RenderViewHost;
class WebContents;
}
@@ -34,18 +33,18 @@ class PopupControllerCommon {
gfx::NativeView container_view() { return container_view_; }
content::WebContents* web_contents() { return web_contents_; }
// Callback used to register with RenderViewHost. This can only be set once,
// or else a callback may be registered that will not be removed
// (crbug.com/338070). Call will crash if callback is already set.
void SetKeyPressCallback(content::RenderWidgetHost::KeyPressEventCallback);
// Register listener for key press events with the current RenderViewHost
// associated with |web_contents_|. If callback has already been registered,
// this has no effect.
void RegisterKeyPressCallback();
// Remove previously registered callback, assuming that the current
// RenderViewHost is the same as when it was originally registered. Safe to
// call even if the callback is not currently registered.
void RemoveKeyPressCallback();
@@ -65,9 +64,9 @@ class PopupControllerCommon {
// listen for keyboard events.
content::WebContents* web_contents_;
// The RenderViewHost that this object has registered its keyboard press
// callback with.
- content::RenderViewHost* key_press_event_target_;
+ content::RenderWidgetHost* key_press_event_target_;
content::RenderWidgetHost::KeyPressEventCallback key_press_event_callback_;

Powered by Google App Engine
@@ -34,18 +33,18 @@ class PopupControllerCommon {
gfx::NativeView container_view() { return container_view_; }
content::WebContents* web_contents() { return web_contents_; }
- // Callback used to register with RenderViewHost. This can only be set once,
- // or else a callback may be registered that will not be removed
+ // Callback used to register with RenderWidgetHost. This can only be set
+ // once, or else a callback may be registered that will not be removed
// (crbug.com/338070). Call will crash if callback is already set.
void SetKeyPressCallback(content::RenderWidgetHost::KeyPressEventCallback);
@@ -34,18 +33,18 @@ class PopupControllerCommon {
// (crbug.com/338070). Call will crash if callback is already set.
void SetKeyPressCallback(content::RenderWidgetHost::KeyPressEventCallback);
- // Register listener for key press events with the current RenderViewHost
- // associated with |web_contents_|. If callback has already been registered,
- // this has no effect.
+ // Register listener for key press events with the current RenderWidgetHost
+ // associated with focused frame in |web_contents_|. If callback has already
+ // been registered, this has no effect.
void RegisterKeyPressCallback();
// Remove previously registered callback, assuming that the current
@@ -34,18 +33,18 @@ class PopupControllerCommon {
void RegisterKeyPressCallback();
// Remove previously registered callback, assuming that the current
- // RenderViewHost is the same as when it was originally registered. Safe to
+ // RenderWidgetHost is the same as when it was originally registered. Safe to
// call even if the callback is not currently registered.
void RemoveKeyPressCallback();
@@ -65,9 +64,9 @@ class PopupControllerCommon {
// listen for keyboard events.
content::WebContents* web_contents_;
- // The RenderViewHost that this object has registered its keyboard press
+ // The RenderWidgetHost that this object has registered its keyboard press
// callback with.
This is Rietveld 408576698